:py:mod:`piel.models.frequency.utils`
=====================================

.. py:module:: piel.models.frequency.utils


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.utils.compose_custom_model_library_from_defaults



.. py:function:: compose_custom_model_library_from_defaults(custom_models: dict) -> dict

   Compose the default models with the custom models.

   :param custom_models: Custom models dictionary.
   :type custom_models: dict

   :returns: Composed models dictionary.
   :rtype: dict
